@@ -9,10 +9,11 @@ Run test:
 
 """
 
-import requests_mock
 import unittest
 from unittest import mock
 
+import requests_mock
+
 from airflow_provider_hightouch.operators.hightouch import HightouchTriggerSyncOperator
 
 
@@ -21,11 +22,10 @@ from airflow_provider_hightouch.operators.hightouch import HightouchTriggerSyncO
     AIRFLOW_CONN_HIGHTOUCH_DEFAULT="http://https%3A%2F%2Ftest.hightouch.io%2F",
 )
 class TestHightouchOperator(unittest.TestCase):
-
     @requests_mock.mock()
     def test_hightouch_operator(self, requests_mock):
         requests_mock.post(
-            "https://test.hightouch.io/api/v1/rest/triggerSync/1",
+            "https://test.hightouch.io/api/v2/rest/run/1",
             json={"success": "it worked"},
         )
         operator = HightouchTriggerSyncOperator(task_id="run", sync_id=1)
